@@ -1,5 +1,5 @@
 #
-# $Id: Split.pm,v 0.32 2004/01/01 02:04:37 st.schubiger Exp $
+# $Id: Split.pm,v 0.33 2004/01/01 18:23:23 st.schubiger Exp $
 
 package Dir::Split;
 
@@ -12,6 +12,8 @@ use File::Copy 'cp';
 use File::Path;
 use File::Spec;
 
+our $VERSION = 0.33;
+
 our (# external refs
         $Source_dir_ref, # scl
         $Target_dir_ref, # scl
@@ -46,8 +48,6 @@ our (# external refs
         $Suffix,
     );
 
-our $VERSION = 0.32;
-
 =head1 NAME
 
 Dir::Split - Split the files of a directory to subdirectories.
@@ -126,8 +126,8 @@ See EXAMPLES to gain an understanding how numeric splitting works.
                               file_sort      =>         '+',
                 },
 
-                suffix  => {  continue_num   =>         'y',
-                              separator      =>         '-',
+                suffix  => {  separator      =>         '-',
+                              continue_num   =>         'y',
                               length         =>           5,
                 },
  );
@@ -257,7 +257,7 @@ string - lower/upper case of the suffix.
 
 sub new {
     my ($pkg, $Opt_ref) = @_;
-    croak q~Invalid arguments: new (\%behavior)~
+    croak q~Syntax: Dir::Split->new (\%behavior)~
       unless ref $Opt_ref eq 'HASH';
 
     my $class = ref ($pkg) || $pkg;
@@ -286,15 +286,9 @@ sub _tie_var {
         else { $my_hash{$key} = $$Opt_ref{$key} }
     }
 
-    return \%my_hash;
+    \%my_hash;
 };
 
-#
-# DESTROY() - object destructor
-#
-
-sub DESTROY { }
-
 =head2 split ( \$source_dir, \$target_dir )
 
 Split files to subdirectories.
@@ -313,7 +307,7 @@ if none, it will return undef.
 sub split {
     my $self = shift;
     ($Source_dir_ref, $Target_dir_ref) = @_;
-    croak q~Invalid arguments: split (\$source_dir, \$target_dir)~
+    croak q~Syntax: $obj->split (\$source_dir, \$target_dir)~
       unless ref $Source_dir_ref eq 'SCALAR' && ref $Target_dir_ref eq 'SCALAR';
 
     # opts refs
@@ -484,9 +478,10 @@ sub _suffix_num {
         foreach (@dirs) {
             # extract exist. identifier
             ($_) = /(.+?)$sep(.*)/;
-            next unless $$Ident_ref eq $_;
             # increase suffix to highest number
-            $$Suffix_ref = $2 if $2 > $$Suffix_ref;
+            if ($$Ident_ref eq $_ && $2 !~ /\w/) {
+               $$Suffix_ref = $2 if $2 > $$Suffix_ref;
+            }
         }
     }
 
@@ -515,7 +510,7 @@ sub _move {
     my $sub_move = "_move_$$Mode_ref";
     $self->$sub_move;
 
-    return $$Ret_f_moved_ref ? $$Ret_f_moved_ref : undef;
+    $$Ret_f_moved_ref ? $$Ret_f_moved_ref : undef;
 }
 
 #
@@ -567,8 +562,7 @@ sub _move_char {
 sub _dir_read {
     shift; my ($dir_ref, $items_ref) = @_;
 
-    opendir D, $$dir_ref or
-      croak qq~Could not open dir $$dir_ref for read-access: $!~;
+    opendir D, $$dir_ref or croak qq~Could not open dir $$dir_ref for read-access: $!~;
     @$items_ref = readdir D; splice (@$items_ref, 0, 2);
     closedir D or croak qq~Could not close dir $$dir_ref: $!~;
 }
@@ -610,9 +604,9 @@ sub _cp_unlink {
         warn "$path_full exists.\n" if $$Warn_ref eq 'all' || $$Warn_ref eq 'files';
         return unless $$Override_ref eq 'all' || $$Override_ref eq 'files';
     }
-    cp ($file, $path_full) or
+    cp $file, $path_full or
       croak qq~Could not copy file $file to subdir $path_full: $!~;
-    unlink ($file) or croak qq~Could not remove file $file: $!~;
+    unlink $file or croak qq~Could not remove file $file: $!~;
 
     $$Ret_f_moved_ref++;
 }
